%==================================================================================================
% PSAM12 LATEX TEMPLATE 0.2
% Developed by: Luke Herbert
% Thanks to Armin Zimmermann for a similar template upon which this is partly based.
% March 2014:  fix reference section font (Diego Mandelli)
%==================================================================================================
%===COMPILATION MESSAGE============================================================================
\typeout{-------------------------------------------}
\typeout{USING PSAM12 LATEX TEMPLATE 0.2}
\typeout{-------------------------------------------}
%===CLASS DEFINITION===============================================================================
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{PSAM12}
\LoadClass[11pt,oneside,a4paper]{article}
%===BASE PACKAGES==================================================================================
%Note: The order in which packages are loaded is fragile!
\usepackage{nag}												% Nag about outdated packages
\usepackage[utf8]{inputenc}								% Allows input of tex files encoded in UTF8
\usepackage[english]{babel}								% Allows langauge switching (English is default)
\usepackage[letterspace=10]{microtype}					% Improve font appearance
\usepackage[T1]{fontenc}									% Set font encoding for output PDF to T1
\usepackage{lmodern}											% Latin Modern fonts
\usepackage{textcomp}										% Provide missing TS1 fonts'
\usepackage[hyperfootnotes=false]{hyperref}			% Hypertext Links (Later packages overide parts)
\usepackage{xcolor}											% Allow for color (used in footer)
\usepackage{titling}											% Customize title
\usepackage[runin]{abstract} 								% Run-in Abstract
\usepackage{amsmath,amssymb,latexsym}					% AMS and other symbols
\usepackage{wordlike}										% Look more like a MS word document
\usepackage[bf]{caption}									% Set caption style
\usepackage[autostyle, babel]{csquotes}				% Improved Quotes
\usepackage[hang,flushmargin,norule,symbol]{footmisc}		% Setup footnotes
\usepackage[style=ieee,backend=bibtex8]{biblatex}	% Base style IEEE + backend setup
%===Biblatex========================================================================================
\ExecuteBibliographyOptions{sorting=nyt}				% Sorting papers by Name/Year/Title
\renewbibmacro*{bbx:savehash}{}							% Prevent same Authors replaced by dash
%===MARGINS=========================================================================================
\special{papersize=210mm,297mm}							% if complied via PS/DVI should keep page size
\usepackage[margin=2.5cm]{geometry}						% 2.5 cm page margins
\setlength{\parindent}{0cm}								% No para indent
\setlength{\parskip}{11pt plus 3mm minus 3mm}
\setlength{\skip\footins}{0.5in}							% Add space between text and footnotes section
%===TITLE STYLE=====================================================================================
\usepackage[explicit]{titlesec} % Allows customization of titles
\titleformat{\section}[block]{\bfseries\rmfamily}{\thesection.}{0.5em}{\MakeUppercase{#1}} 
\titleformat{\subsection}[block]{\bfseries\rmfamily}{\thesubsection.}{0.5em}{#1} 
\titlespacing*{\section}{0pt}{2pt plus 1ex minus .2ex}{2pt plus .2ex}
\titlespacing*{\subsection}{0pt}{2pt plus 1ex minus .2ex}{2pt plus .2ex}
%===FOOTER STYLE====================================================================================
\usepackage{fancyhdr} % Headers and footers
\pagestyle{fancy} % All pages have headers and footers
\renewcommand{\headrulewidth}{0pt} % No upper line
\fancyhead{} % Blank out the default header
\fancyfoot{} % Blank out the default footer
\fancyfoot[C]{\color{black!50}{Probabilistic Safety Assessment and Management PSAM 12, June 2014, Honolulu, Hawaii}} % Custom header text
%===SET DATA COMMANDS===============================================================================
\newcommand{\SetTitle}[1]{\def\PSAMtitle{#1}}
\newcommand{\SetKeywords}[1]{\def\PSAMkeywords{#1}}
\newcommand{\SetAbstract}[1]{\def\PSAMabstract{#1}}
\newcommand{\SetAuthor}[1]{\def\PSAMauthor{#1}}
\newcommand{\SetAddress}[1]{\def\PSAMaddress{#1}}
%===Create Title====================================================================================
\newcommand{\CreateTitle}{
	\begin{minipage}{1.0\textwidth}
		\begin{center}
			{\bfseries\fontsize{14pt}{14pt}\selectfont \PSAMtitle}
		\end{center}	
		\begin{center}
			{\bfseries\fontsize{12pt}{12pt}\selectfont \PSAMauthor}
		\end{center}
		\begin{center}
			{\fontsize{11pt}{11pt}\selectfont \PSAMaddress}
		\end{center}
		\hrule
		\vspace*{0.2cm}
		\textbf{Abstract:} \PSAMabstract
		\newline \phantom{.} \newline
		\textbf{Keywords:} \PSAMkeywords
		\vspace*{0.05cm}
		\hrule
	\end{minipage} 
}
%===NO Extra space between list items (Robin's lowlist)============================================
\def\@listI{\leftmargin\leftmargini \parsep 0pt plus 1pt%
\topsep  2pt plus 4pt minus 2pt%
\itemsep 0pt plus 1pt}
\def\@listii{\leftmargin\leftmarginii \parsep 0pt plus 1pt%
\topsep  2pt plus 4pt minus 2pt%
\itemsep 0pt plus 1pt}
%==Footnote commands======================
\makeatletter
\def\CorrespondingAuthor{$^{*}$\xdef\@thefnmark{}\@footnotetext}
\makeatother